"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.scratchUploadInstructions = void 0;
const anchor_1 = require("@project-serum/anchor");
const spl_token_1 = require("@solana/spl-token");
const web3_js_1 = require("@solana/web3.js");
const bn_js_1 = __importDefault(require("bn.js"));
const programAddress = new web3_js_1.PublicKey("2e1wdyNhUvE76y6yUCvah2KaviavMJYKoRun8acMRBZZ");
const tokenMint = new web3_js_1.PublicKey("SHDWyBxihqiCj6YekG2GUr7wqKLeLAMK1gHZck9pL6y");
const uploader = new web3_js_1.PublicKey("972oJTFyjmVNsWM4GHEGPWUomAiJf2qrVotLtwnKmWem");
function getStorageAccount(key, accountSeed) {
    return __awaiter(this, void 0, void 0, function* () {
        return web3_js_1.PublicKey.findProgramAddress([
            Buffer.from("storage-account"),
            key.toBytes(),
            accountSeed.toTwos(2).toArrayLike(Buffer, "le", 4),
        ], programAddress);
    });
}
function getStakeAccount(storageAccount) {
    return __awaiter(this, void 0, void 0, function* () {
        return web3_js_1.PublicKey.findProgramAddress([Buffer.from("stake-account"), storageAccount.toBytes()], programAddress);
    });
}
function getStorageConfigPDA() {
    return __awaiter(this, void 0, void 0, function* () {
        return web3_js_1.PublicKey.findProgramAddress([Buffer.from("storage-config")], programAddress);
    });
}
function scratchUploadInstructions({ provider, drive, files, }) {
    return __awaiter(this, void 0, void 0, function* () {
        const instructions = [];
        const idl = yield anchor_1.Program.fetchIdl(programAddress, provider);
        const program = new anchor_1.Program(idl, programAddress, provider);
        const storageInputAsBytes = files.reduce((acc, file) => acc + file.size, 0);
        const userInfo = (yield web3_js_1.PublicKey.findProgramAddress([Buffer.from("user-info"), provider.wallet.publicKey.toBytes()], program.programId))[0];
        let userInfoData = yield program.account.userInfo.fetchNullable(userInfo);
        const accountSeed = userInfoData
            ? new bn_js_1.default(userInfoData.accountCounter)
            : new bn_js_1.default(0);
        let storageAccount = (yield getStorageAccount(provider.wallet.publicKey, accountSeed))[0];
        // Retrieve stakeAccount
        const stakeAccount = (yield getStakeAccount(storageAccount))[0];
        const ownerAta = yield spl_token_1.Token.getAssociatedTokenAddress(spl_token_1.ASSOCIATED_TOKEN_PROGRAM_ID, spl_token_1.TOKEN_PROGRAM_ID, tokenMint, provider.wallet.publicKey, true);
        const storageRequested = new bn_js_1.default(storageInputAsBytes.toString()); // 2^30 B <==> 1GB
        const storageConfig = (yield getStorageConfigPDA())[0];
        const instruction = yield program.methods
            .initializeAccount(name, storageRequested, null)
            .accounts({
            storageConfig,
            userInfo,
            storageAccount,
            stakeAccount,
            tokenMint,
            owner1: provider.wallet.publicKey,
            uploader: uploader,
            owner1TokenAccount: ownerAta,
            systemProgram: web3_js_1.SystemProgram.programId,
            tokenProgram: spl_token_1.TOKEN_PROGRAM_ID,
            rent: web3_js_1.SYSVAR_RENT_PUBKEY,
        })
            .instructions();
    });
}
exports.scratchUploadInstructions = scratchUploadInstructions;
//# sourceMappingURL=shdw.js.map